@@ -1,44 +1,23 @@
+import math
 import matplotlib.pyplot as plt
 import pyregion
 
-import math
-
-try:
-    from astropy.io import fits as pyfits
-except ImportError:
-    import pyfits
-
-# At some point, pyfits.Card.fromstring has changed from unbound
-# method to bounded method.
-
-if pyfits.Card.fromstring.__self__: # 
-    def pyfits_card_fromstring(l):
-        return pyfits.Card.fromstring(l)
-else:
-    def pyfits_card_fromstring(l):
-        c = pyfits.Card()
-        return c.fromstring(l)
 
 def demo_header():
-    cards = pyfits.CardList()
-    for l in open("sample_fits01.header"):
-        card = pyfits_card_fromstring(l.strip())
-        cards.append(card)
-    h = pyfits.Header(cards)
-    return h
+    from astropy.io.fits import Header
+    return Header.fromtextfile("sample_fits01.header")
 
 
 def show_region(fig, region_list):
     h = demo_header()
 
     n = len(region_list)
-    nx = int(math.ceil(n**.5))
-    ny = int(math.ceil(1.*n/nx))
-
+    nx = int(math.ceil(n ** .5))
+    ny = int(math.ceil(1. * n / nx))
 
     nrows_ncols = (ny, nx)
 
-    grid = [plt.subplot(ny, nx, i+1) for i in range(n)]
+    grid = [plt.subplot(ny, nx, i + 1) for i in range(n)]
 
     for ax, reg_name in zip(grid, region_list):
         ax.set_aspect(1)
@@ -58,4 +37,3 @@ def show_region(fig, region_list):
             t.set_visible(False)
 
     return grid
-
